==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/admin_customers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_customers.lang.inc.php 2018-08-24
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ALL' => 'Alle',
	'BUTTON_DELETE_GUEST_ACCOUNTS' => 'Gastkonten löschen',
	'BUTTON_LOGIN_AS_CUSTOMER' => 'Als Kunde einloggen',
	'ENTRY_COMMENTS' => 'Anmerkungen',
	'ENTRY_MEMO' => 'Memo:',
	'ENTRY_NEW_PASSWORD' => 'Neues Passwort:',
	'ENTRY_PASSWORD_CUSTOMER' => 'Passwort:',
	'ENTRY_PAYMENT_UNALLOWED' => 'Nicht erlaubte Zahlungsmodule:',
	'ENTRY_SHIPPING_UNALLOWED' => 'Nicht erlaubte Versandmodule:',
	'HEADING_DELETE_GUEST_ACCOUNTS' => 'Gast-Konten löschen',
	'CONFIRM_DELETE_GUEST_ACCOUNTS' => 'Möchten Sie wirklich alle Gast-Konten löschen?',
	'HEADING_SUB_TITLE' => 'Kunden',
	'HEADING_TITLE' => 'Kunden',
	'HEADING_TITLE_SEARCH' => 'Suche:',
	'HEADING_TITLE_STATUS' => 'Kundengruppe',
	'MAILBEEZ_CONVERSATIONS' => 'MailBeez - Tickets',
	'MAILBEEZ_NOTIFICATIONS' => 'MailBeez - Meldungen',
	'MAILBEEZ_OVERVIEW' => 'MailBeez - Kunden Insight',
	'NEW_ORDER' => 'Neue Bestellung ?',
	'PLEASE_SELECT' => 'Auswählen',
	'TABLE_HEADING_ACCOUNT_CREATED' => 'Erstellt am',
	'TABLE_HEADING_ACCOUNT_TYPE' => 'Konto',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_DATE_ADDED' => 'Datum',
	'TABLE_HEADING_DATE_LAST_LOGON' => 'Letzte Anmeldung',
	'TABLE_HEADING_FIRSTNAME' => 'Vorname',
	'TABLE_HEADING_GROUPIMAGE' => 'Icon',
	'TABLE_HEADING_LASTNAME' => 'Nachname',
	'TABLE_HEADING_NEW_VALUE' => 'Neuer Status',
	'TEXT_ACCOUNT' => 'Ja',
	'TEXT_ALL_CUSTOMERS' => 'Alle Gruppen',
	'TEXT_CREATE' => 'Erstellen',
	'TEXT_CUSTOMERS_ID' => 'Kundennr.',
	'TEXT_CUSTOMER_CREDIT' => 'Guthaben:',
	'TEXT_DATE' => 'Datum',
	'TEXT_DATE_ACCOUNT_CREATED' => 'Erstellt am:',
	'TEXT_DATE_ACCOUNT_LAST_MODIFIED' => 'letzte Änderung:',
	'TEXT_DELETE_INTRO' => 'Wollen Sie diesen Kunden wirklich löschen?',
	'TEXT_DELETE_REVIEWS' => '%s Rezension(en) löschen',
    'TEXT_CANT_DELETE_SUPER_ADMIN' => 'Der Hauptadmin kann nicht gelöscht werden.',
	'TEXT_GUEST' => 'Nein',
	'TEXT_INFORMATIONS' => 'Informationen',
	'TEXT_INFO_ADMIN_HAS_NO_RIGHTS' => 'ACHTUNG! Dieser Admin hat noch keine Administrationsrechte. Sie können die Rechte über den folgenden Link bearbeiten: ',
	'TEXT_INFO_COUNTRY' => 'Land:',
	'TEXT_INFO_DATE_LAST_LOGON' => 'letzte Anmeldung:',
	'TEXT_INFO_HEADING_DELETE_CUSTOMER' => 'Kunden löschen',
	'TEXT_INFO_HEADING_STATUS_CUSTOMER' => 'Kundengruppe',
	'TEXT_INFO_NUMBER_OF_LOGONS' => 'Anzahl der Anmeldungen:',
	'TEXT_INFO_NUMBER_OF_REVIEWS' => 'Anzahl der Kundenrezensionen:',
	'TEXT_INSERT_ELEMENT' => 'Neues Element',
	'TEXT_IP_LOG_CUSTOMER_ADVERTISER' => 'Werber',
	'TEXT_IP_LOG_CUSTOMER_IP' => 'Kunden-IP',
	'TEXT_IP_LOG_HOST' => 'Host',
	'TEXT_IP_LOG_LAST_LOGIN' => 'Letzter Login',
	'TEXT_IP_REFERER_URL' => 'Referenz-URL',
	'TEXT_MARKED_ELEMENTS' => 'Markiertes Element',
	'TEXT_NEW_MEMO' => 'Neues Memo',
	'TEXT_NO_CUSTOMER_HISTORY' => '--Keine Änderung bisher--',
	'TEXT_NONE_IN_LIST' => 'Keine in der Liste',
	'TEXT_POSTER' => 'Verfasser',
	'TEXT_SELECT' => '--Auswahl--',
	'TEXT_TITLE' => 'Titel',
	'TEXT_MEMO' => 'Memo Text',
	'TEXT_VOUCHER_CODE' => 'Gutscheincode einlösen:',
	'TYPE_BELOW' => 'Bitte unten eingeben',
	'TEXT_SUBTOTAL' => 'Zwischensumme',
	'TEXT_TOTAL' => 'Summe'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_customers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_customers.lang.inc.php 2020-10-07
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ALL' => 'Alle',
	'BUTTON_DELETE_GUEST_ACCOUNTS' => 'Gastkonten löschen',
	'BUTTON_LOGIN_AS_CUSTOMER' => 'Als Kunde einloggen',
	'ENTRY_COMMENTS' => 'Anmerkungen',
	'ENTRY_MEMO' => 'Memo:',
	'ENTRY_NEW_PASSWORD' => 'Neues Passwort:',
	'ENTRY_PASSWORD_CUSTOMER' => 'Passwort:',
	'ENTRY_PAYMENT_UNALLOWED' => 'Nicht erlaubte Zahlungsmodule:',
	'ENTRY_SHIPPING_UNALLOWED' => 'Nicht erlaubte Versandmodule:',
	'HEADING_DELETE_GUEST_ACCOUNTS' => 'Gast-Konten löschen',
	'CONFIRM_DELETE_GUEST_ACCOUNTS' => 'Möchtest du wirklich alle %s Gast-Konten löschen?',
	'HEADING_SUB_TITLE' => 'Kunden',
	'HEADING_TITLE' => 'Kunden',
	'HEADING_TITLE_SEARCH' => 'Suche:',
	'HEADING_TITLE_STATUS' => 'Kundengruppe',
	'MAILBEEZ_CONVERSATIONS' => 'MailBeez - Tickets',
	'MAILBEEZ_NOTIFICATIONS' => 'MailBeez - Meldungen',
	'MAILBEEZ_OVERVIEW' => 'MailBeez - Kunden Insight',
	'NEW_ORDER' => 'Neue Bestellung ?',
	'PLEASE_SELECT' => 'Auswählen',
	'TABLE_HEADING_ACCOUNT_CREATED' => 'Erstellt am',
	'TABLE_HEADING_ACCOUNT_TYPE' => 'Konto',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_DATE_ADDED' => 'Datum',
	'TABLE_HEADING_DATE_LAST_LOGON' => 'Letzte Anmeldung',
	'TABLE_HEADING_FIRSTNAME' => 'Vorname',
	'TABLE_HEADING_GROUPIMAGE' => 'Icon',
	'TABLE_HEADING_LASTNAME' => 'Nachname',
	'TABLE_HEADING_NEW_VALUE' => 'Neuer Status',
	'TEXT_ACCOUNT' => 'Ja',
	'TEXT_ALL_CUSTOMERS' => 'Alle Gruppen',
	'TEXT_CREATE' => 'Erstellen',
	'TEXT_CUSTOMERS_ID' => 'Kundennr.',
	'TEXT_CUSTOMER_CREDIT' => 'Guthaben:',
	'TEXT_DATE' => 'Datum',
	'TEXT_DATE_ACCOUNT_CREATED' => 'Erstellt am:',
	'TEXT_DATE_ACCOUNT_LAST_MODIFIED' => 'letzte Änderung:',
	'TEXT_DELETE_INTRO' => 'Willst du diesen Kunden wirklich löschen?',
	'TEXT_DELETE_REVIEWS' => '%s Rezension(en) löschen',
    'TEXT_CANT_DELETE_SUPER_ADMIN' => 'Der Hauptadmin kann nicht gelöscht werden.',
	'TEXT_GUEST' => 'Nein',
	'TEXT_INFORMATIONS' => 'Informationen',
	'TEXT_INFO_ADMIN_HAS_NO_RIGHTS' => 'ACHTUNG! Dieser Admin hat noch keine Administrationsrechte. Du kannst die Rechte über den folgenden Link bearbeiten: ',
	'TEXT_INFO_COUNTRY' => 'Land:',
	'TEXT_INFO_DATE_LAST_LOGON' => 'letzte Anmeldung:',
	'TEXT_INFO_HEADING_DELETE_CUSTOMER' => 'Kunden löschen',
	'TEXT_INFO_HEADING_STATUS_CUSTOMER' => 'Kundengruppe',
	'TEXT_INFO_NUMBER_OF_LOGONS' => 'Anzahl der Anmeldungen:',
	'TEXT_INFO_NUMBER_OF_REVIEWS' => 'Anzahl der Kundenrezensionen:',
	'TEXT_INSERT_ELEMENT' => 'Neues Element',
	'TEXT_IP_LOG_CUSTOMER_ADVERTISER' => 'Werber',
	'TEXT_IP_LOG_CUSTOMER_IP' => 'Kunden-IP',
	'TEXT_IP_LOG_HOST' => 'Host',
	'TEXT_IP_LOG_LAST_LOGIN' => 'Letzter Login',
	'TEXT_IP_REFERER_URL' => 'Referenz-URL',
	'TEXT_MARKED_ELEMENTS' => 'Markiertes Element',
	'TEXT_NEW_MEMO' => 'Neues Memo',
	'TEXT_NO_CUSTOMER_HISTORY' => '--Keine Änderung bisher--',
	'TEXT_NONE_IN_LIST' => 'Keine in der Liste',
	'TEXT_POSTER' => 'Verfasser',
	'TEXT_SELECT' => '--Auswahl--',
	'TEXT_TITLE' => 'Titel',
	'TEXT_MEMO' => 'Memo Text',
	'TEXT_VOUCHER_CODE' => 'Gutscheincode einlösen:',
	'TYPE_BELOW' => 'Bitte unten eingeben',
	'TEXT_SUBTOTAL' => 'Zwischensumme',
	'TEXT_TOTAL' => 'Summe'
);
